﻿using Exam.Application.Interface.Exam;
using Exam.Infrastructure.Data.Entity;
using Exam.Infrastructure.Data.Extensions;
using Exam.Share.ViewResponses.Exam;
using Hotline.Application.Exam.Constants.ApiRoutes;
using Hotline.Application.Exam.Service.ExamManages;
using Hotline.Share.Dtos.ExamManages;
using Hotline.Share.Dtos.TestPapers;
using Hotline.Share.Requests.Exam;
using Hotline.Share.Requests.Sourceware;
using Hotline.Share.ViewResponses.Exam;
using Hotline.Share.ViewResponses.Sourcewares;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using XF.Domain.Authentications;

namespace Hotline.Api.Controllers.Exam
{
    public class ExtractRuleController : BaseController
    {
        private readonly IExtractRuleService _extractRuleService;
        private readonly ISessionContext _sessionContext;
        public ExtractRuleController(IExtractRuleService extractRuleService,ISessionContext sessionContext)
        {
            _extractRuleService = extractRuleService;
            _sessionContext = sessionContext;
        }

        /// <summary>
        /// 新增考试标签
        /// </summary>
        /// <param name="extractRuleDto"></param>
        /// <returns></returns>
        [HttpPost(ExtractRuleApiRoute.Add)]
        public async Task Add([FromBody] ExtractRuleDto extractRuleDto)
        {
            extractRuleDto.InitRequest(_sessionContext);
            await _extractRuleService.AddAsync(extractRuleDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 修改考试标签
        /// </summary>
        /// <param name="extractRuleDto"></param>
        /// <returns></returns>
        [HttpPut(ExtractRuleApiRoute.Update)]
        public async Task Update([FromBody] ExtractRuleDto extractRuleDto)
        {
            extractRuleDto.InitRequest(_sessionContext);
            await _extractRuleService.UpdateAsync(extractRuleDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 删除考试标签
        /// </summary>
        /// <param name="entityQueryRequest"></param>
        /// <returns></returns>
        [HttpDelete(ExtractRuleApiRoute.Delete)]

        public async Task Delete(EntityQueryRequest entityQueryRequest)
        {
            await _extractRuleService.DeleteAsync(entityQueryRequest, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取课件分页列表
        /// </summary>
        /// <param name="sourcewarePagedRequest"></param>
        /// <returns></returns>
        [HttpPost(ExtractRuleApiRoute.GetPagedList)]
        public async Task<ExtractRulePageViewResponse> GetPagedList([FromBody] ExtractRulePagedRequest sourcewarePagedRequest)
        {
            var sourcewarePageViewResponse = await _extractRuleService.GetPagedListAsync(sourcewarePagedRequest);

            return sourcewarePageViewResponse as ExtractRulePageViewResponse;
        }


        /// <summary>
        /// 获取课件分类
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet(ExtractRuleApiRoute.Get)]
        public async Task<ExtractRuleDto> Get(string id)
        {
            var extractRuleDto = await _extractRuleService.GetAsync(new EntityQueryRequest
            {
                Id = id
            });

            return extractRuleDto;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="tagQuestionRequest"></param>
        /// <returns></returns>
        [HttpPost(ExtractRuleApiRoute.GetTagQuestionCount)]
        public async Task<List<TagQuestionViewResponse>> GetTagQuestionCount([FromBody]TagQuestionRequest tagQuestionRequest)
        {
            var tagQuestionViewResponses = await _extractRuleService.GetTagQuestionCount(tagQuestionRequest);

            return tagQuestionViewResponses;
        }
    }
}
